@@ -85,11 +85,7 @@ QList< QWidget* > EdgeTypesDelegate::createItemWidgets(const QModelIndex &index)
     connect(title, &QLineEdit::textEdited, this, &EdgeTypesDelegate::onNameChanged);
     connect(propertiesButton, &QToolButton::clicked, this, &EdgeTypesDelegate::showPropertiesDialog);
 
-    return QList<QWidget*>() << colorButton
-                             << direction
-                             << title
-                             << idLabel
-                             << propertiesButton;
+    return { colorButton, direction, title, idLabel, propertiesButton };
 }
 
 void EdgeTypesDelegate::updateItemWidgets(const QList< QWidget* > widgets, const QStyleOptionViewItem& option, const QPersistentModelIndex& index) const
@@ -176,11 +172,12 @@ void EdgeTypesDelegate::onDirectionSwitched()
     QModelIndex index = focusedIndex();
     EdgeType::Direction direction = static_cast<EdgeType::Direction>(
         index.data(EdgeTypeModel::DirectionRole).toInt());
-    if (direction == EdgeType::Bidirectional) {
-        emit directionChanged(index, EdgeType::Unidirectional);
-    } else {
-        emit directionChanged(index, EdgeType::Bidirectional);
-    }
+
+    const EdgeType::Direction newDirection = direction == EdgeType::Bidirectional
+        ? EdgeType::Unidirectional
+        : EdgeType::Bidirectional;
+
+    emit directionChanged(index, newDirection);
 }
 
 void EdgeTypesDelegate::showPropertiesDialog()
@@ -190,4 +187,5 @@ void EdgeTypesDelegate::showPropertiesDialog()
     QPointer<EdgeTypeProperties> dialog = new EdgeTypeProperties(0);
     dialog->setType(type->self());
     dialog->exec();
+    delete dialog;
 }
